@@ -2,8 +2,10 @@ from typing import Tuple
 
 import argparse
 
+from .xls_parser import XlsParserFormat
 
-def parse() -> Tuple[str, str]:
+
+def parse() -> Tuple[str, str, XlsParserFormat]:
     parser = argparse.ArgumentParser(
         description="Парсер xls/xlsx-файлов для загрузки в реестр",
     )
@@ -12,5 +14,8 @@ def parse() -> Tuple[str, str]:
     parser.add_argument("--output", "-o", type=str,
                         help="Путь к директории с выводом",
                         required=False, default=None)
+    parser.add_argument("--format", type=XlsParserFormat,
+                        help="Формат данных",
+                        required=False, default=XlsParserFormat.first_format)
     options = parser.parse_args()
-    return options.folder, options.output
+    return options.folder, options.output, options.format
